#!/bin/bash

###############################################################################
#                   header  
# for normal queue: bsc_es, for fast testing: debug
###############################################################################
#
#SBATCH --qos=bsc_es
#SBATCH -A bsc32
#SBATCH --cpus-per-task=1
#SBATCH -n 273
#SBATCH --time=00:60:00
#SBATCH --job-name=awicm3
#SBATCH --mail-type=NONE
#SBATCH --exclusive
#SBATCH --output=/home/bsc32/bsc32044/awi-cm3/tests/coupled/awicm3-v3.1_experiment_from_levante/awicm3.out
#SBATCH --error=/home/bsc32/bsc32044/awi-cm3/tests/coupled/awicm3-v3.1_experiment_from_levante/awicm3.err

# -------------------------------------------------------------------------
# *** Start the run
# -------------------------------------------------------------------------

##########          load modules           ##########

#module load intel/2018.4
module load impi/2018.4
#module load mkl/2018.4
module load netcdf/4.4.1.1
#module load python/3.6.1
module load eccodes/2.8.0
module load hdf5/1.8.19

export ECCODES_SAMPLES_PATH=/apps/ECCODES/2.8.0/INTEL/share/eccodes/ifs_samples/grib1/ 


##########  components and core configuration ##########

export OIFS="./master.exe"
export OIFS_CORES="128"
export FESOM="./fesom.x"
export FESOM_CORES="144"
export RNFMAPPER="./rnfmap.exe"
export RNFMAPPER_CORES="1"

export FESOM_USE_CPLNG="active"
export ECE_CPL_NEMO_LIM="false"
export ECE_CPL_FESOM_FESIM="false"
export ECE_AWI_CPL_FESOM="true"

##########           build the command        ##########
# Use the launch function from the platform configuration file
export exp_name=awi3

cmd="${FESOM_CORES} ${FESOM} -- \
     ${OIFS_CORES} ${OIFS} -v ecmwf -e ${exp_name} -- \
     ${RNFMAPPER_CORES} ${RNFMAPPER}" 

#has_config nemo && \
#    cmd="${xio_numproc} ${xio_exe_file} -- \
#         ${nem_numproc} ${nem_exe_file} -- \
#         ${ifs_numproc} ${ifs_exe_file} -v ecmwf -e ${exp_name}" || \
#    cmd="${ifs_numproc} ${ifs_exe_file} -v ecmwf -e ${exp_name}"

#has_config lpjg && cmd=${cmd}" -- ${lpjg_numproc} ${lpjg_exe_file} guess.ins -parallel"
#has_config tm5  && cmd=${cmd}" -- ${tm5_numproc}  ${tm5_exe_file} tm5-run.rc"
#has_config amip && cmd=${cmd}" -- ${amip_numproc} ${amip_exe_file}"
#has_config nemo && cmd=${cmd}" -- ${rnf_numproc} ${rnf_exe_file}" 

function launch()
{
    # version using srun
    echo $#
    # was originally commented........
    #cmd="srun "
    _task1=-1
    NBTASKS=0
    rm -rf conf.txt
    while (( "$#" ))
    do
        nranks=$1
        executable=./$(basename $2)
        shift
        shift

        _task0=$((_task1+1))
        _task1=$((_task0+nranks-1))

        cmd="${_task0}-${_task1} ${executable}"

        NBTASKS=$((NBTASKS+nranks))

        while (( "$#" )) && [ "$1" != "--" ]
        do
            cmd+=" $1"
            shift
        done
        echo ${cmd} >>conf.txt
        shift || true
    done
    export CONF_FILE=conf.txt
    #cat $CONF_FILE
    ## we use intel
    #export OMP_NUM_THREADS=1

    
   # srun --qos=debug -l --kill-on-bad-exit=1 --cpu_bind=none --multi-prog $CONF_FILE
    # mpirun -n $FESOM_CORES ./$FESOM : -n $OIFS_CORES ./$OIFS -v ecmwf -e ${exp_name} : -n $RNFMAPPER_CORES ./$RNFMAPPER
    # original
    srun  --multi-prog $CONF_FILE

}

t1=$(date +%s)
launch $cmd
#cmd="mpirun -n $FESOM_CORES ./$FESOM : -n $OIFS_CORES ./$OIFS -v ecmwf -e ${exp_name} : -n $RNFMAPPER_CORES ./$RNFMAPPER"
#srun $cmd
t2=$(date +%s)

tr=$(date -d "0 -$t1 sec + $t2 sec" +%T)

# Checking for IFS success
if [ -f ifs.stat ]
    then
        if [ "$(awk 'END{print $3}' ifs.stat)" == "CNT0" ]
        then
            echo "Leg successfully completed according to IFS log file 'ifs.stat'."
        else
            echo "Leg not completed according to IFS log file 'ifs.stat'."
        fi
    else
        echo  "ERROR: IFS log file 'ifs.stat' not found after run."
fi

